==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/messages/sr/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Potvrdi</strong> akciju',
    '<strong>Latest</strong> updates' => '<strong>Novo</strong> ažuriranje',
    '<strong>Mail</strong> summary' => '<strong>Mail</strong> sažetak',
    'Actions' => 'Akcije',
    'Add:' => 'Dodaj:',
    'Administration' => 'Administracija',
    'All' => 'Sve',
    'Allow' => 'Dopusti',
    'Allow content from external source' => 'Dozvoli sadrzaj sa spoljnih izvora',
    'Always allow content from this provider!' => 'Uvek dozvoli sadrzaj ovog provajdera',
    'An error occurred while handling your last action. (Handler not found).' => 'Došlo je do greške pri rukovanju vašom poslednjom radnjom. (Handler nije pronađen).',
    'An unexpected error occurred while loading the search result.' => 'Došlo je do neočekivane greške prilikom učitavanja rezultata pretraživanja.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Došlo je do neočekivane greške. Ako se to nastavi, kontaktirajte administratora web sajta.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Došlo je do neočekivane greške servera. Ako se to nastavi, kontaktirajte administratora web sajta.',
    'Back' => 'Nazad',
    'Back to dashboard' => 'Povratak na upravljačku stranu',
    'Cancel' => 'Poništi',
    'Choose language:' => 'Odaberite jezik:',
    'Close' => 'Zatvori',
    'Collapse' => 'Spusti',
    'Confirm' => 'Potvrdi',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Izvor sadržaja Addon mora biti  HActiveRecordContent ili HActiveRecordContentAddon!',
    'Copy to clipboard' => 'Kopirati u klipbord',
    'Could not find content of addon!' => 'Nije moguće pronaći sadržaj addona!',
    'Could not find requested page.' => 'Nike moguće pronaći traženu stranicu.',
    'Default' => 'Podrazumevano',
    'Delete' => 'Izbriši',
    'Deny' => 'Odbiti',
    'Do you really want to perform this action?' => 'Želite li zaista da uradite ovu akciju?',
    'Edit' => 'Uredi',
    'Error' => 'Greska',
    'Error while running your last action (Invalid request method).' => 'Greška prilikom izvođenja poslednje radnje (nevažeći način zahteva).',
    'Error:' => 'Greska:',
    'Expand' => 'Proširi',
    'Export' => 'Izvoz',
    'Info:' => 'Info:',
    'Invalid request method!' => 'Nevažeći način zahteva!',
    'It looks like you may have taken the wrong turn.' => 'Izgleda da ste se pogrešno skrenuli.',
    'Language' => 'Jezik',
    'Loading...' => 'Učitavam...',
    'Login' => 'Prijava',
    'Logo of {appName}' => 'Logo {appName}',
    'Logout' => 'Odjava',
    'Menu' => 'Meni',
    'Module is not enabled on this content container!' => 'Modul nije omogućen na ovom kontejneru sadržaja!',
    'New profile image' => 'Nova profilna slika',
    'Next' => 'Dalje',
    'No error information given.' => 'Nema podataka o grešci.',
    'Oooops...' => 'Oooops...',
    'Open' => 'Otvori',
    'Please type at least 3 characters' => 'Upišite najmanje 3 znaka',
    'Please type at least {count} characters' => 'Molimo unesite najmanje {count} znakova',
    'Powered by {name}' => 'Pokreće {name}',
    'Profile dropdown' => 'Padajući meni profila',
    'Profile picture of {displayName}' => 'Profilna slika od {displayName}',
    'Save' => 'Sačuvaj',
    'Saved' => 'Sačuvano',
    'Search' => 'Pretraži',
    'Search...' => 'Pretraga...',
    'Select Me' => 'Izaberi mene',
    'Settings' => 'Postavke',
    'Show less' => 'Prikaži manje',
    'Show more' => 'Prikaži više',
    'Some files could not be uploaded:' => 'Neke datoteke nisu prenesene:',
    'Text could not be copied to clipboard' => 'Tekst nije mogao biti kopiran u privremenu memoriju',
    'Text has been copied to clipboard' => 'Tekst je kopiran u privremenu memoriju',
    'The date has to be in the past.' => 'Datum mora biti u prošlosti.',
    'The file has been deleted.' => 'Datoteka je izbrisana.',
    'The requested resource could not be found.' => 'Traženi resurs nije moguće pronaći.',
    'The space has been archived.' => 'Prostor je arhiviran.',
    'The space has been unarchived.' => 'Prostor je de-arhiviran.',
    'Time Zone' => 'Vremenska zona',
    'Toggle comment menu' => 'Prikazivanje menia komentara',
    'Toggle panel menu' => 'Prikazivanje menia na panelu',
    'Toggle post menu' => 'Prikazivanje menia pošte',
    'Toggle stream entry menu' => 'Prikazivanje menia unosa u strim',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Postoje nesacuvane izmene, želite li zaista da napustite ovu stranicu?',
    'Unsubscribe' => 'Otkažite pretplatu',
    'Upload' => 'Dodaj',
    'Upload file' => 'Dodaj datoteku',
    'You are not allowed to run this action.' => 'Nije vam dozvoljena ova akcija.',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'My Profile' => '',
    'No results' => '',
    'Show all results' => '',
    'Stop impersonation' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
    '{nFormatted}B' => '',
    '{nFormatted}K' => '',
    '{nFormatted}M' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/messages/sr/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Potvrdi</strong> akciju',
    '<strong>Latest</strong> updates' => '<strong>Novo</strong> ažuriranje',
    '<strong>Mail</strong> summary' => '<strong>Mail</strong> sažetak',
    'Actions' => 'Akcije',
    'Add:' => 'Dodaj:',
    'Administration' => 'Administracija',
    'All' => 'Sve',
    'Allow' => 'Dopusti',
    'Allow content from external source' => 'Dozvoli sadrzaj sa spoljnih izvora',
    'Always allow content from this provider!' => 'Uvek dozvoli sadrzaj ovog provajdera',
    'An error occurred while handling your last action. (Handler not found).' => 'Došlo je do greške pri rukovanju vašom poslednjom radnjom. (Handler nije pronađen).',
    'An unexpected error occurred while loading the search result.' => 'Došlo je do neočekivane greške prilikom učitavanja rezultata pretraživanja.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Došlo je do neočekivane greške. Ako se to nastavi, kontaktirajte administratora web sajta.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Došlo je do neočekivane greške servera. Ako se to nastavi, kontaktirajte administratora web sajta.',
    'Back' => 'Nazad',
    'Back to dashboard' => 'Povratak na upravljačku stranu',
    'Cancel' => 'Poništi',
    'Choose language:' => 'Odaberite jezik:',
    'Close' => 'Zatvori',
    'Collapse' => 'Spusti',
    'Confirm' => 'Potvrdi',
    'Content Addon source must be instance of ContentActiveRecord or ContentAddonActiveRecord!' => 'Izvor sadržaja Addon mora biti  ContentActiveRecord ili ContentAddonActiveRecord!',
    'Copy to clipboard' => 'Kopirati u klipbord',
    'Could not find content of addon!' => 'Nije moguće pronaći sadržaj addona!',
    'Could not find requested page.' => 'Nike moguće pronaći traženu stranicu.',
    'Default' => 'Podrazumevano',
    'Delete' => 'Izbriši',
    'Deny' => 'Odbiti',
    'Do you really want to perform this action?' => 'Želite li zaista da uradite ovu akciju?',
    'Edit' => 'Uredi',
    'Enter security code above' => 'unesite sigurnosni kod',
    'Error' => 'Greska',
    'Error while running your last action (Invalid request method).' => 'Greška prilikom izvođenja poslednje radnje (nevažeći način zahteva).',
    'Error:' => 'Greska:',
    'Expand' => 'Proširi',
    'Export' => 'Izvoz',
    'Info:' => 'Info:',
    'Invalid request method!' => 'Nevažeći način zahteva!',
    'It looks like you may have taken the wrong turn.' => 'Izgleda da ste se pogrešno skrenuli.',
    'Language' => 'Jezik',
    'Loading...' => 'Učitavam...',
    'Login' => 'Prijava',
    'Logo of {appName}' => 'Logo {appName}',
    'Logout' => 'Odjava',
    'Menu' => 'Meni',
    'Module is not enabled on this content container!' => 'Modul nije omogućen na ovom kontejneru sadržaja!',
    'New profile image' => 'Nova profilna slika',
    'Next' => 'Dalje',
    'No error information given.' => 'Nema podataka o grešci.',
    'Oooops...' => 'Oooops...',
    'Open' => 'Otvori',
    'Please type at least 3 characters' => 'Upišite najmanje 3 znaka',
    'Please type at least {count} characters' => 'Molimo unesite najmanje {count} znakova',
    'Powered by {name}' => 'Pokreće {name}',
    'Profile dropdown' => 'Padajući meni profila',
    'Profile picture of {displayName}' => 'Profilna slika od {displayName}',
    'Save' => 'Sačuvaj',
    'Saved' => 'Sačuvano',
    'Search' => 'Pretraži',
    'Search...' => 'Pretraga...',
    'Select Me' => 'Izaberi mene',
    'Settings' => 'Postavke',
    'Show less' => 'Prikaži manje',
    'Show more' => 'Prikaži više',
    'Some files could not be uploaded:' => 'Neke datoteke nisu prenesene:',
    'Text could not be copied to clipboard' => 'Tekst nije mogao biti kopiran u privremenu memoriju',
    'Text has been copied to clipboard' => 'Tekst je kopiran u privremenu memoriju',
    'The date has to be in the past.' => 'Datum mora biti u prošlosti.',
    'The file has been deleted.' => 'Datoteka je izbrisana.',
    'The requested resource could not be found.' => 'Traženi resurs nije moguće pronaći.',
    'The space has been archived.' => 'Prostor je arhiviran.',
    'The space has been unarchived.' => 'Prostor je de-arhiviran.',
    'Time Zone' => 'Vremenska zona',
    'Toggle comment menu' => 'Prikazivanje menia komentara',
    'Toggle panel menu' => 'Prikazivanje menia na panelu',
    'Toggle post menu' => 'Prikazivanje menia pošte',
    'Toggle stream entry menu' => 'Prikazivanje menia unosa u strim',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Postoje nesacuvane izmene, želite li zaista da napustite ovu stranicu?',
    'Unsubscribe' => 'Otkažite pretplatu',
    'Upload' => 'Dodaj',
    'Upload file' => 'Dodaj datoteku',
    'You are not allowed to run this action.' => 'Nije vam dozvoljena ova akcija.',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'Back to login' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'I\'m not a robot' => '',
    'My Profile' => '',
    'No results' => '',
    'Show all results' => '',
    'Stop impersonation' => '',
    'Switch network' => '',
    'Verified' => '',
    'We couldn\'t verify that you\'re human. Please check the box again.' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
    '{nFormatted}B' => '',
    '{nFormatted}K' => '',
    '{nFormatted}M' => '',
];
